@@ -1,7 +1,7 @@
 package Elastijk;
 use strict;
 use warnings;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use JSON ();
 use URI::Escape qw(uri_escape);
@@ -92,8 +92,8 @@ Elastijk - A specialized ElasticSearch client.
 =head1 DESCRIPTION
 
 Elastijk is a ElasticSearch client library. It uses L<Hijk>, a HTTP client that
-implements a tiny subset of HTTP/1.1 that makes it just enough to talk to
-ElasticSearch via HTTP.
+implements a tiny subset of HTTP/1.1 just enough to talk to ElasticSearch via
+HTTP.
 
 Elastijk provided low-level functions that are almost identical as using HTTP
 client, and a object-oriented sugar-layer to make it easier to use. The following
@@ -113,24 +113,29 @@ is fine. All key-value pairs are shallow-copied from `new` method:
 
 Here's a full list of key-value pairs that are consumed:
 
-=over 4
-
-=item host => Str "localhost"
-
-=item port => Str "9200"
-
-=item index => Str (optional)
-
-=item type => Str (optional)
-
-=back
+    host  => Str "localhost"
+    port  => Str "9200"
+    index => Str (optional)
+    type  => Str (optional)
 
 The values for C<index> and C<type> act like a "default" value and they are only
-used in methods that could use them. Those methods should also takes new
-values for index or type and overrieds the defaults.
+used in methods that could use them. Those methods should also takes new values
+for index or type and overrieds the defaults.
 
 =head1 OBJECT METHODS
 
+=head2 search( $param1 => $value1, $param2 => $value2, ... )
+
+This method encapsulate <request body search|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-body.html>
+
+The arguments are key-value pairs from the API documents.
+
+=head2 uri_search ( ... )
+
+This method encapsulate C<uri search|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-uri-request.html>
+
+The arguments are key-value pairs from the API documents.
+
 =head2 exists( index => Str )
 
 Check if the given index exists.
